#!/bin/bash
#
# install.sh - install script for bootsplash progress bar support
#
#

PWD="`pwd`"
PATCH="bootsplash-patch"

if [ "$UID" -ne "0" ]; then
	echo "$0 must be started as root!"
	echo "Exiting..."
	exit 1
fi

# Check for epm
if [ ! -x /usr/bin/epm ]; then
	echo "$0 depends on package 'epm'"
	echo "Please run $0 a second time after you have emerged 'epm'"
	exit 1
fi

# Check baselayout version
BVERSION="`epm -q baselayout | cut -d '-' -f 2`"
VERSION="1.8.5.9"

if [ "$BVERSION" != "$VERSION" ]; then
	cat << EOF 
***********************************************************************
* WARNING: This script will patch some files of the  baselayout 
* package (/sbin/rc, /sbin/functions.sh, /etc/init.d/halt.sh)
* but the version of this patch ($VERSION) does not match your 
* baselayouts version ($BVERSION). If you want to proceed, I will
* make a backup of each file (/sbin/rc~, /sbin/function.sh~,...).
* Otherwise read the INSTALL file and try to manually patch the files.
***********************************************************************

EOF

	echo -n "Should I proceed ? (y/n): "
	read input
	[ "$input" != "y" ] && exit 0
fi

echo "Applying patches:"
patch -d / -p 1 -b -i "${PWD}/${PATCH}-${VERSION}.diff"

echo -n "Moving /sbin/splash to /sbin/splash.bin:"
if [ -f /sbin/splash.bin ]; then
	echo -e "\nMhm, /sbin/splash.bin already exists, leaving it untouched!"
else
	mv /sbin/splash /sbin/splash.bin
	echo " OK"
fi

echo -n "Installing wrapper script /sbin/splash:"
if [ -f /sbin/splash ]; then
	echo -e "\nMhm, /sbin/splash already exists, leaving it untouched!"
else
	install -m 755 "${PWD}/splash" /sbin/
	echo " OK"
fi

echo "Done."
